ss.cc.constants: Functions to find out constants of the relative range distribution.
Description
These functions compute the constants d2, d3 and c4 to get
estimators of the standard deviation to set control limits.
Usage
ss.cc.getd2(n = NA)
Arguments
n
Sample size
Value
A numeric value for the constant.
References
Cano, Emilio L., Moguerza, Javier M. and Redchuk, Andres.
2012. Six Sigma with {R}. Statistical Engineering for
Process Improvement, Use R!, vol. 36. Springer, New York.
http://www.springer.com/statistics/book/978-1-4614-3651-5.