ss.heli: Creates a pdf file with the design of the Paper Helicopter
Description
The pdf file contains a template with lines and indications
to build the paper helicopter described in many SixSigma
publications.
Usage
ss.heli()
Arguments
Value
No value is returned. A pdf file is saved in the working
directory
Details
The pdf file must be printed in A4 paper, without adjusting
size to paper.
References
George Box. Teaching engineers experimental design with a
paper helicopter. Quality Engineering,
4(3):453--459, 1992.
Cano, Emilio L., Moguerza, Javier M. and Redchuk, Andres.
2012. Six Sigma with {R}. Statistical Engineering for
Process Improvement, Use R!, vol. 36. Springer, New York.
http://www.springer.com/statistics/book/978-1-4614-3651-5.