Usage
ss.ci(x, sigma2 = NA, alpha = 0.05, data = NA, xname = "x",
approx.z = FALSE, main = "Confidence Interval for the Mean", digits = 3,
sub = "", ss.col = c("#666666", "#BBBBBB", "#CCCCCC", "#DDDDDD",
"#EEEEEE"))Arguments
x
A numeric vector with the variable data
sigma2
The population variance, if known
alpha
The eqn{\alpha} error used to compute the $100*(1-\alpha)%$ confidence interval
data
The data frame containing the vector
xname
The name of the variable to be shown in the graph
approx.z
If TRUE it uses z statistic instead of t when sigma is unknown and sample size
is greater than 30. The default is FALSE, change only if you want to compare with
results obtained with the old-fashioned method mentioned in some books.
main
The main title for the graph
digits
Significant digits for output
sub
The subtitle for the graph (recommended: six sigma project name)
ss.col
A vector with colors