Learn R Programming

SixSigma (version 0.9-3)

ss.rr: Gage R & R (Measurement System Assessment)

Description

Performs Gage R&R analysis for the assessment of the measurement system of a process. Related to the Measure phase of the DMAIC strategy of Six Sigma.

Usage

ss.rr(var, part, appr, lsl = NA, usl = NA, sigma = 6, data, main = "Six Sigma Gage R&R Study", sub = "", alphaLim = 0.05, errorTerm = "interaction", digits = 4)

Arguments

var
Measured variable
part
Factor for parts
appr
Factor for appraisers (operators, machines, ...)
lsl
Numeric value of lower specification limit used with USL to calculate Study Variation as %Tolerance
usl
Numeric value of upper specification limit used with LSL to calculate Study Variation as %Tolerance
sigma
Numeric value for number of std deviations to use in calculating Study Variation
data
Data frame containing the variables
main
Main title for the graphic output
sub
Subtitle for the graphic output (recommended the name of the project)
alphaLim
Limit to take into account interaction
errorTerm
Which term of the model should be used as error term (for the model with interation)
digits
Number of decimal digits for output

Value

Analysis of Variance Table/s. Variance composition and %Study Var. Graphics.
anovaTable
The ANOVA table of the model
anovaRed
The ANOVA table of the reduced model (without interaction, only if interaction not significant)
varComp
A matrix with the contribution of each component to the total variation
studyVar
A matrix with the contribution to the study variation
ncat
Number of distinct categories

Details

Performs an R&R study for the measured variable, taking into account part and appraiser factors. It outputs the sources of Variability, and six graphs: bar chart with the sources of Variability, plots by appraiser, part and interaction and x-bar and R control charts.

References

Automotive Industry Action Group. (2010). Measurement Systems Analysis (Fourth Edition). AIAG.

Cano, Emilio L., Moguerza, Javier M. and Redchuk, Andres. 2012. Six Sigma with R. Statistical Engineering for Process Improvement, Use R!, vol. 36. Springer, New York. http://www.springer.com/statistics/book/978-1-4614-3651-5.

Montgomery, D. C. (2009). Introduction to Statistical Quality Control (Sixth Edition ed.). New York: Wiley & Sons, Inc.

See Also

ss.data.rr

Examples

Run this code
ss.rr(time1, prototype, operator, data = ss.data.rr, 
	sub = "Six Sigma Paper Helicopter Project", 
	alphaLim = 0.05,
	errorTerm = "interaction")

Run the code above in your browser using DataLab